@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef SYSTEMVOLUMEPLUGINWIN_H
-#define SYSTEMVOLUMEPLUGINWIN_H
+#pragma once
 
 #include <QMap>
 #include <QObject>
@@ -16,21 +15,17 @@
 #include <endpointvolume.h>
 #include <mmdeviceapi.h>
 
-#ifdef __MINGW32__
-#include <initguid.h>
-#endif
-
 #define PACKET_TYPE_SYSTEMVOLUME QStringLiteral("kdeconnect.systemvolume")
 #define PACKET_TYPE_SYSTEMVOLUME_REQUEST QStringLiteral("kdeconnect.systemvolume.request")
 
-class Q_DECL_EXPORT SystemvolumePlugin : public KdeConnectPlugin
+class SystemvolumePlugin : public KdeConnectPlugin
 {
     Q_OBJECT
 
 public:
     explicit SystemvolumePlugin(QObject *parent, const QVariantList &args);
     ~SystemvolumePlugin();
-    bool receivePacket(const NetworkPacket &np) override;
+    void receivePacket(const NetworkPacket &np) override;
     void connected() override;
 
 private:
@@ -46,5 +41,3 @@ private:
     bool sendSinkList();
     HRESULT setDefaultAudioPlaybackDevice(QString &name, bool enabled);
 };
-
-#endif // SYSTEMVOLUMEPLUGINWIN_H
